@@ -13,10 +13,11 @@ It provides functionality for
 from __future__ import annotations
 
 import asyncio
+from collections.abc import Awaitable, Iterator
 from enum import Enum
 from itertools import chain
 import logging
-from typing import TYPE_CHECKING, Any, Awaitable, Callable, Iterator, cast
+from typing import TYPE_CHECKING, Any, Callable, cast
 
 from xknx.dpt.dpt_color import XYYColor
 from xknx.remote_value import (
