@@ -33,7 +33,9 @@ from .knxip_enum import (
     KNXMedium,
     SearchRequestParameterType,
 )
+from .routing_busy import RoutingBusy
 from .routing_indication import RoutingIndication
+from .routing_lost_message import RoutingLostMessage
 from .search_request import SearchRequest
 from .search_request_extended import SearchRequestExtended
 from .search_response import SearchResponse
@@ -44,6 +46,7 @@ from .session_request import SessionRequest
 from .session_response import SessionResponse
 from .session_status import SessionStatus
 from .srp import SRP
+from .timer_notify import TimerNotify
 from .tunnelling_ack import TunnellingAck
 from .tunnelling_request import TunnellingRequest
 
@@ -77,7 +80,9 @@ __all__ = [
     "HostProtocol",
     "KNXIPServiceType",
     "KNXMedium",
+    "RoutingBusy",
     "RoutingIndication",
+    "RoutingLostMessage",
     "SearchRequest",
     "SearchRequestExtended",
     "SearchRequestParameterType",
@@ -89,6 +94,7 @@ __all__ = [
     "SessionResponse",
     "SessionStatus",
     "SRP",
+    "TimerNotify",
     "TunnellingAck",
     "TunnellingRequest",
 ]
