@@ -93,7 +93,7 @@ class CEMIFlags:
     BROADCAST = 0x1000
 
     # Bit 1/3+2
-    PRIORITY_SYSTE = 0x0000
+    PRIORITY_SYSTEM = 0x0000
     PRIORITY_NORMAL = 0x0400
     PRIORITY_URGENT = 0x0800
     PRIORITY_LOW = 0x0C00
