@@ -18,10 +18,13 @@ from .remote_value_dpt_value_1_ucount import RemoteValueDptValue1Ucount
 from .remote_value_raw import RemoteValueRaw
 from .remote_value_scaling import RemoteValueScaling
 from .remote_value_scene_number import RemoteValueSceneNumber
-from .remote_value_sensor import RemoteValueNumeric, RemoteValueSensor
+from .remote_value_sensor import (
+    RemoteValueNumeric,
+    RemoteValueSensor,
+    RemoteValueString,
+)
 from .remote_value_setpoint_shift import RemoteValueSetpointShift
 from .remote_value_step import RemoteValueStep
-from .remote_value_string import RemoteValueString
 from .remote_value_switch import RemoteValueSwitch
 from .remote_value_temp import RemoteValueTemp
 from .remote_value_updown import RemoteValueUpDown
